
addpath %add path to ISSM bin/ and lib/ directories

% Cluster options
optionloadonly       = 1;
idruns               = [1:210]; %ID of parallelized runs
outname0             = 'StochClimGrIS';
codepath             = ''; %path to directory with ISSM binaries
execpath             = ''; %path to directory for simulation execution
coresrequested       = 24;
memrequested         = 5; %GB
timerequested        = 160*60; %minutes

nglac                = 11;
CalvingVals          = [240,1100,5,5,4400,2050,2100,990,600,2030,0];

%%% Inputs %%%
pathload    = './Inputs/myRunEnsp5pc2_ClvVals9dt7tm1048.mat'; 
corrmatloc  = './Inputs/corrMatGrIStrans24May2022.csv'; 

%%% Load at transient solution index corresponds to 1000 years %%%
if(contains(pathload,'myRunEnsp5pc2_ClvVals9dt7tm1048'))
   iiload = 4; %load 4th transient time step from myRunEnsp5pc2_ClvVals9dt7tm1048.mat (998.1 years of RefSpin)
end

%%% Run settings %%%
deltat        = 7/365;
endtime       = 500;
reqoutputs    = {'IceVolume','GroundedArea','TotalCalvingFluxLevelset','TotalSmb','TotalCalvingMeltingFluxLevelset'};
outputfreq    = 52;
lvlReinit     = 1;
sigmaRatioSMB = 1/3; %noise-to-mean ratio for variability
sigmaRatioTF  = 1/3; %noise-to-mean ratio for variability
phi1smb       = 2/3;
phi1tf        = 0.9;

%%% Load model from previous iteration %%%
md     = loadmodel(pathload);

%%% Set initial conditions %%%
md.geometry.thickness        = md.results.TransientSolution(iiload).Thickness;
md.initialization.vx         = md.results.TransientSolution(iiload).Vx;
md.initialization.vy         = md.results.TransientSolution(iiload).Vy;
md.initialization.vel        = md.results.TransientSolution(iiload).Vel;
md.mask.ocean_levelset       = md.results.TransientSolution(iiload).MaskOceanLevelset;
md.initialization.pressure   = md.results.TransientSolution(iiload).Pressure;
md.geometry.base             = md.results.TransientSolution(iiload).Base;
md.geometry.surface          = md.results.TransientSolution(iiload).Surface;
md.mask.ice_levelset         = md.results.TransientSolution(iiload).MaskIceLevelset;;

%%% Levelset %%%
levelsetvals                          = md.results.TransientSolution(iiload).MaskIceLevelset;
flagsRefined                          = getExpRefinedGlaciers(md.mesh.x,md.mesh.y);
levelsetvals(flagsRefined)            = NaN;
md.levelset.spclevelset               = levelsetvals;
md.levelset.reinit_frequency          = lvlReinit;

%%% Initialize calving rates %%%
asl = find(md.geometry.bed>0);
bsl = find(md.geometry.bed<=0);
md.calving.calvingrate = 0*ones(md.mesh.numberofvertices,1);
indsSepRefined         = getExpSepRefinedGlaciers(md.mesh.x,md.mesh.y);

%%% Stochastic forcing %%%
corrmatglob = csvread(corrmatloc);
meanValsSMB = 1*md.smb.beta0; %take mean from non-stochastic spin-up
meanValsTF  = 1*md.frontalforcings.beta0; %take mean from non-stochastic spin-up
sigmavals    = [sigmaRatioSMB*meanValsSMB,sigmaRatioTF*meanValsTF];
covmat_glob  = (diag(sigmavals))*corrmatglob*(diag(sigmavals));
md.stochasticforcing.isstochasticforcing = 1;
md.stochasticforcing.stochastictimestep  = 1.0;
md.stochasticforcing.fields              = [{'SMBautoregression'},{'FrontalForcingsRignotAutoregression'}];
md.stochasticforcing.default_id          = md.smb.basin_id; %basin for each element
md.stochasticforcing.defaultdimension    = 19; %number of basins
md.stochasticforcing.covariance          = covmat_glob; 

%%% SMB autoregression %%%
md.smb.phi     = phi1smb*ones(md.smb.num_basins,1);
md.smb.beta0   = meanValsSMB.*(1-sum(md.smb.phi,2)');

%%% TF autoregression %%%
md.frontalforcings.phi   = phi1tf*ones(md.frontalforcings.num_basins,1);
md.frontalforcings.beta0 = meanValsTF.*(1-sum(md.frontalforcings.phi,2)');

%%% Transient parameters %%%
md.settings.output_frequency   = outputfreq;
md.timestepping.start_time     = 0;
md.timestepping.time_step      = deltat;
md.timestepping.final_time     = endtime;
md.transient.requested_outputs = reqoutputs;
md.results                     = {}; %remove any old results
md.transient.ismovingfront     = 1; %allow for moving front
md.transient.isgroundingline   = 1; %allow for moving GL (i.e. moving mask.ocean_levelset)
md.transient.isstressbalance   = 1;
md.transient.ismasstransport   = 1;
md.transient.issmb             = 1;
md.transient.isthermal         = 0;
md.inversion.iscontrol         = 0;

%%% Parallelization %%%
md.settings.waitonlock = 0;
md.cluster = pace('np',coresrequested,'login','loginname','codepath',codepath,'executionpath',execpath,'mem',memrequested,'time',timerequested);
%%% Calving adjustment per glacier %%%
for gg=1:numel(indsSepRefined)
    md.calving.calvingrate(indsSepRefined{gg}) = CalvingVals(gg);
end
md.calving.calvingrate(asl) = 0;

for ii=idruns
    md.miscellaneous.name = [outname0,'_id',num2str(ii)]; %Run name
    md = solve(md,'Transient','runtimename',false,'loadonly',optionloadonly);
    if(optionloadonly==1)
        md = loadresultsfromcluster(md);
        time = [md.results.TransientSolution(:).time];
        IceVolume        = [md.results.TransientSolution(:).IceVolume];
        GrArea           = [md.results.TransientSolution(:).GroundedArea];
        TotalSmb         = [md.results.TransientSolution(:).TotalSmb];
        TotalCalving     = [md.results.TransientSolution(:).TotalCalvingFluxLevelset];
        TotalFrontalMelt = [md.results.TransientSolution(:).TotalCalvingMeltingFluxLevelset];
        outmat  = [time;IceVolume;GrArea;TotalSmb;TotalCalving;TotalFrontalMelt];
        outname = [execpath,'/',outname0,'_id',int2str(ii),'TimeSeries.csv'];
        writematrix(outmat,outname);

        %savename = [execpath,outname0,'_pc1calvensvals',num2str(ii),'.mat'];
        %save(savename,'md','-v7.3') %save md
        
	rmdir([execpath,outname0,'_id',num2str(ii)],'s'); %clean-up
    end
end


